.. :changelog:

History
-------

0.1.0 (2015-08-01)
##################

* First release on PyPI.

0.2.0 (2015-08-04)
##################

* Added AutocompleteChoiceFilter
* Add CSS-class settings for CrispyFormFilter
* Drop strict requirements for django-tinycontent

0.3.0 (2015-08-04)
##################

* Split class to independent package to resolve dependencies issues

0.6.0 (2015-10-25)
##################

* A lot

0.10.0 (2015-11-21)
###################

* Add asci_slugifier
* Add absolute_import to crispy_forms

0.11.0 (2015-12-10)
###################

* Fix support of dj19 by autocomplete_light API changes

0.12.0 (2016-12-4)
##################

* Add ``atom.ext.guardian.tests.PermissionStatusMixin``


0.12.8 (2016-12-16)
###################

* Mark code as Python 3 compatible

0.14.0 (2017-06-1)
##################

* Add ``atom.mixins.AdminTestCaseMixin``

0.14.1 (2017-06-1)
##################

* Add base class validation in ``atom.mixins.AdminTestCaseMixin``

0.14.2 (2017-06-1)
##################

* Fix username and message in ``atom.mixins.AdminTestCaseMixin``

0.14.3 (2017-06-1)
##################

* Fix django 1.8-1.9 compatibility of ``atom.mixins``

0.15.0 (2017-07-21)
###################

* Add management command ``generate_factory``, ``generate_routers``, ``generate_serializers``, ``generate_viewsets``, ``generate_viewsets_tests``
* Add serializer ``atom.ext.contenttypes.ContentTypeSerializer`` , ``atom.ext.sites.serializer.SiteSerializer``
* Add mixin ``atom.ext.rest_framework.ViewSetTestCaseMixin``

0.15.1 (2017-08-4)
##################

* Fix management commands import

0.15.2 (2017-08-4)
##################

* Fix README.rst format

0.15.3 (2017-08-4)
##################

* Fix HISTORY.rst format
